package hdm.mi.growbros;

import com.fasterxml.jackson.databind.ObjectMapper;
import hdm.mi.growbros.models.plant.Plant;
import hdm.mi.growbros.service.PlantsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Profile;

import java.util.List;


@SpringBootApplication
public class GrowBrosApplication {
    private static final Logger log = LoggerFactory.getLogger(GrowBrosApplication.class);

    public static void main(String[] args) {
        SpringApplication.run(GrowBrosApplication.class, args);
    }

    @Bean
    @Profile("!test")
    public CommandLineRunner plants(PlantsService plantsService) {
        return (args) -> {
            List<String> json = List.of("""
                    {"name":"Salat (Gartensalat)","latinName":"Lactuca sativa var. crispa","growingTips":"Salate eignen sich sehr gut als ‚Lückenfüller‘. Sie benötigen ausreichend Feuchtigkeit und haben einen vergleichsweise geringen Nährstoffbedarf. Durch eine geschickte Auswahl lassen sich Salate das ganze Jahr über anbauen: im Frühjahr und Frühsommer Kopf- und Schnitt-/Pflücksalate; im Sommer und Herbst Zichoriensalate und Eissalate sowie Feldsalat (v.a. im Herbst, Winter). Für eine kontinuierliche Ernte am besten in zeitlichen Abständen säen bzw. pflanzen. Arten und Sorten müssen dabei an die jeweilige Jahreszeit angepasst sein, z.B. beginnen Frühjahrssorten bei zu viel Hitze zu schießen. Dabei bildet sich ein langer Stiel und die Blätter werden bitter. Nach einigen Wochen kommen oben kleine Blüten zum Vorschein, woraus sich viele halbmondförmige Samen bilden. Diese können für das Folgejahr abgesammelt werden oder verteilen sich selbst im Beet, wenn du sie stehen lässt.\\n","description":"Salat steht als Überbegriff für viele Blattgemüse. Kopfsalate bilden - wie der Name schon sagt - einen Kopf und werden am Stück geerntet. Pflücksalate kann man kontinuierlich ernten, wenn man jeweils nur einzelne Blätter abpflückt. ","origin":"Gartensalate sind gezüchtete Lattichgewächse (Lactuca sativa) mit Urpsrung in Südeuropa, Nordafrika und Indien. Darunter fallen Kopfsalate (Batavia, Eissalat), Schnitt-/Pflücksalate (Lollo Rosso/Bionda, Eichblatt) und Römersalate.","plantWeekStart":12,"plantWeekEnd":35,"harvestWeekStart":15,"harvestWeekEnd":44,"growthDuration":6,"nutrientDemand":"MEDIUM","lightingDemand":"MEDIUM","waterDemand":"WET","groundType":null,"imageUrl":"https://d3t240q2dksnz7.cloudfront.net/a4cbb94a099179235fdd5696ae5f3833.jpg"}
                    """, """
                    {"name":"Kirschgroße gelbe Traube","latinName":"","description":"Ein Massenträger mit gigantischen Klumpentrauben von teils mehr als 100 Früchten.Nahezu kirschgroß, gelb, leicht oval und gut platzfest. Saftig würzig und süß schmeckend. Vermutlich Verbesserung einer Wildform.\\nÜber 2m hoch wachsend. Gleicht etwas 'Aurianticum' und 'Mirabell Gelb'. Relativ früh reifend.","origin":null,"plantWeekStart":20,"plantWeekEnd":22,"harvestWeekStart":26,"harvestWeekEnd":41,"growthDuration":12.5,"nutrientDemand":null,"lightingDemand":null,"waterDemand":null,"groundType":null,"imageUrl":"https://d3t240q2dksnz7.cloudfront.net/a214162d7e999d9fbb19ab75c69a0bdf.jpg"}
                    """);

            ObjectMapper objectMapper = new ObjectMapper();

            try {
                for (String s : json) {
                    Plant plant = objectMapper.readValue(s, Plant.class);
                    plantsService.createPlant(plant);
                }
                log.info("Saved mock plants");
            } catch (Exception e) {
                log.error(e.getMessage());
            }
        };
    }
}
